==> nezha-compute-api-1.7.0-20171102.113714-1-sources.jar: cn/com/duiba/nezha/compute/api/enums/ModelKeyEnum.java <==
package cn.com.duiba.nezha.compute.api.enums;

/**
 * Created by xuezhaoming on 16/8/2.
 */
public enum ModelKeyEnum {

    LR_CTR_MODEL_005("mid_lr_20170302", "特征列表005&数据源映射005"),// 参数优化
    LR_CTR_MODEL_009("mid_lr_cvr_20170505", "cvr_v1"),// 参数优化
    LR_CTR_MODEL_011("mid_lr_ctr_20170531", "ctr_v2"),// 参数优化
    LR_CVR_MODEL_002("mid_lr_cvr_20170531", "cvr_v2"),// 参数优化
    FM_CVR_MODEL_001("mid_fm_cvr_20170531", "fm_cvr_v1"),// 参数优化

    //LR_CTR
    LR_CTR_MODEL_v003("mid_lr_ctr_v003", "lr_ctr_v003_20170711"),
    LR_CTR_MODEL_v004("mid_lr_ctr_v004", "lr_ctr_v004_20170804"),
    LR_CTR_MODEL_v005("mid_lr_ctr_v005", "lr_ctr_v005_20170818"),
    LR_CTR_MODEL_v006("mid_lr_ctr_v006", "lr_ctr_v006_20170914"),
    LR_CTR_MODEL_v007("mid_lr_ctr_v007", "lr_ctr_v007_20171101"),
    LR_CTR_MODEL_v008("mid_lr_ctr_v008", "lr_ctr_v008_20171102"),

    //LR_CVR
    LR_CVR_MODEL_v003("mid_lr_cvr_v003", "lr_cvr_v003_20170711"),
    LR_CVR_MODEL_v004("mid_lr_cvr_v004", "lr_cvr_v004_20170804"),
    LR_CVR_MODEL_v005("mid_lr_cvr_v005", "lr_cvr_v005_20170818"),
    LR_CVR_MODEL_v006("mid_lr_cvr_v006", "lr_cvr_v006_20170914"),
    LR_CVR_MODEL_v007("mid_lr_cvr_v007", "lr_cvr_v007_20171101"),
    LR_CVR_MODEL_v008("mid_lr_cvr_v008", "lr_cvr_v008_20171102"),

    //FM_CTR
    FM_CTR_MODEL_v001("mid_fm_ctr_v001", "fm_ctr_v001_20170711"),
    FM_CTR_MODEL_v002("mid_fm_ctr_v002", "fm_ctr_v002_20170802"),
    FM_CTR_MODEL_v003("mid_fm_ctr_v003", "fm_ctr_v003_20170818"),
    FM_CTR_MODEL_v004("mid_fm_ctr_v004", "fm_ctr_v004_20170925"),
    FM_CTR_MODEL_v005("mid_fm_ctr_v005", "fm_ctr_v005_20170926"),
    FM_CTR_MODEL_v006("mid_fm_ctr_v006", "fm_ctr_v006_20171024"),

    //FM_CVR
    FM_CVR_MODEL_v001("mid_fm_cvr_v001", "fm_cvr_v001_20170711"),
    FM_CVR_MODEL_v002("mid_fm_cvr_v002", "fm_cvr_v002_20170802"),
    FM_CVR_MODEL_v003("mid_fm_cvr_v003", "fm_cvr_v003_20170818"),
    FM_CVR_MODEL_v004("mid_fm_cvr_v004", "fm_cvr_v004_20170925"),
    FM_CVR_MODEL_v005("mid_fm_cvr_v005", "fm_cvr_v005_20170926"),
    FM_CVR_MODEL_v006("mid_fm_cvr_v006", "fm_cvr_v006_20171024"),




    FM_CTR_MODEL_TEST("mid_fm_ctr_test","模型测试Key"),
    FM_CVR_MODEL_TEST("mid_fm_cvr_test","模型测试Key"),
    LR_CTR_MODEL_TEST("mid_lr_test","模型测试Key"),
    ;
    private String index;

    private String desc;

    ModelKeyEnum(String index, String desc) {
        this.index = index;
        this.desc = desc;
    }

    public String  getIndex() {
        return index;
    }

    public String getDesc() {
        return desc;
    }
}

==> nezha-compute-api-1.10.1-20171218.110003-1-sources.jar: cn/com/duiba/nezha/compute/api/enums/ModelKeyEnum.java <==
package cn.com.duiba.nezha.compute.api.enums;

/**
 * Created by xuezhaoming on 16/8/2.
 */
public enum ModelKeyEnum {

    LR_CTR_MODEL_005("mid_lr_20170302", "特征列表005&数据源映射005"),// 参数优化
    LR_CTR_MODEL_009("mid_lr_cvr_20170505", "cvr_v1"),// 参数优化
    LR_CTR_MODEL_011("mid_lr_ctr_20170531", "ctr_v2"),// 参数优化
    LR_CVR_MODEL_002("mid_lr_cvr_20170531", "cvr_v2"),// 参数优化
    FM_CVR_MODEL_001("mid_fm_cvr_20170531", "fm_cvr_v1"),// 参数优化

    //LR_CTR
    LR_CTR_MODEL_v003("mid_lr_ctr_v003", "lr_ctr_v003_20170711"),
    LR_CTR_MODEL_v004("mid_lr_ctr_v004", "lr_ctr_v004_20170804"),
    LR_CTR_MODEL_v005("mid_lr_ctr_v005", "lr_ctr_v005_20170818"),
    LR_CTR_MODEL_v006("mid_lr_ctr_v006", "lr_ctr_v006_20170914"),
    LR_CTR_MODEL_v007("mid_lr_ctr_v007", "lr_ctr_v007_20171101"),
    LR_CTR_MODEL_v008("mid_lr_ctr_v008", "lr_ctr_v008_20171102"),

    //LR_CVR
    LR_CVR_MODEL_v003("mid_lr_cvr_v003", "lr_cvr_v003_20170711"),
    LR_CVR_MODEL_v004("mid_lr_cvr_v004", "lr_cvr_v004_20170804"),
    LR_CVR_MODEL_v005("mid_lr_cvr_v005", "lr_cvr_v005_20170818"),
    LR_CVR_MODEL_v006("mid_lr_cvr_v006", "lr_cvr_v006_20170914"),
    LR_CVR_MODEL_v007("mid_lr_cvr_v007", "lr_cvr_v007_20171101"),
    LR_CVR_MODEL_v008("mid_lr_cvr_v008", "lr_cvr_v008_20171102"),

    //FM_CTR
    FM_CTR_MODEL_v001("mid_fm_ctr_v001", "fm_ctr_v001_20170711"),
    FM_CTR_MODEL_v002("mid_fm_ctr_v002", "fm_ctr_v002_20170802"),
    FM_CTR_MODEL_v003("mid_fm_ctr_v003", "fm_ctr_v003_20170818"),
    FM_CTR_MODEL_v004("mid_fm_ctr_v004", "fm_ctr_v004_20170925"),
    FM_CTR_MODEL_v005("mid_fm_ctr_v005", "fm_ctr_v005_20170926"),
    FM_CTR_MODEL_v006("mid_fm_ctr_v006", "fm_ctr_v006_20171024"),
    FM_CTR_MODEL_v007("mid_fm_ctr_v007", "fm_ctr_v007_20171130"),

    //FM_CVR
    FM_CVR_MODEL_v001("mid_fm_cvr_v001", "fm_cvr_v001_20170711"),
    FM_CVR_MODEL_v002("mid_fm_cvr_v002", "fm_cvr_v002_20170802"),
    FM_CVR_MODEL_v003("mid_fm_cvr_v003", "fm_cvr_v003_20170818"),
    FM_CVR_MODEL_v004("mid_fm_cvr_v004", "fm_cvr_v004_20170925"),
    FM_CVR_MODEL_v005("mid_fm_cvr_v005", "fm_cvr_v005_20170926"),
    FM_CVR_MODEL_v006("mid_fm_cvr_v006", "fm_cvr_v006_20171024"),
    FM_CVR_MODEL_v007("mid_fm_cvr_v007", "fm_cvr_v007_20171130"),



    FM_CTR_MODEL_TEST_V4_1("mid_fm_ctr_test_v4_1","模型测试Key"),
    FM_CVR_MODEL_TEST_V4_1("mid_fm_cvr_test_v4_1","模型测试Key"),

    FM_CTR_MODEL_TEST_V4("mid_fm_ctr_test_v4","模型测试Key V4"),
    FM_CVR_MODEL_TEST_V4("mid_fm_cvr_test_v4","模型测试Key V4"),

    ;
    private String index;

    private String desc;

    ModelKeyEnum(String index, String desc) {
        this.index = index;
        this.desc = desc;
    }

    public String  getIndex() {
        return index;
    }

    public String getDesc() {
        return desc;
    }
}
